<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineOrthogonalTangent</name>
    <message>
        <location filename="../LineOrthogonalTangent.js" line="+70"/>
        <source>Choose line</source>
        <translation>Proszę wskazać linię</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Choose circle, arc or ellipse</source>
        <translation>Proszę wskazać okrąg, łuk lub elipsę</translation>
    </message>
    <message>
        <location line="+139"/>
        <source>No tangent possible</source>
        <translation>Niemożliwa styczność</translation>
    </message>
    <message>
        <location filename="../LineOrthogonalTangentInit.js" line="+2"/>
        <source>Orthogonal / Tange&amp;nt</source>
        <translation>Prostopadła / sty&amp;czna</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line orthogonal to line and tangent to circle, arc or ellipse</source>
        <translation>Rysuje linię prostopadłą do linii i styczną do okręgu, łuku lub elipsy</translation>
    </message>
</context>
</TS>
